@@ -43,9 +43,9 @@ ac_table = {
                 '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
                 '--max-socket-retries', '--dump-interval', '--read-only', '--separated-workspace', '--memory-hwm',
                 '--skip-on-error', '--num-part', '--uses-internal', '--entrypoint', '--pull-latest', '--volumes',
-                '--host', '--port-expose', '--port-grpc', '--port-rest', '--daemon', '--runtime-backend', '--runtime',
-                '--runtime-cls', '--timeout-ready', '--env', '--expose-public', '--show-exc-info', '--pea-id',
-                '--pea-role', '--uses-before', '--uses-after', '--parallel', '--shards', '--polling', '--scheduling',
+                '--host', '--port-expose', '--daemon', '--runtime-backend', '--runtime', '--runtime-cls',
+                '--timeout-ready', '--env', '--expose-public', '--show-exc-info', '--pea-id', '--pea-role',
+                '--uses-before', '--uses-after', '--parallel', '--shards', '--polling', '--scheduling',
                 '--remote-access', '--remote-type', '--pod-role'],
         'flow': ['--help', '--uses', '--logserver', '--logserver-config', '--log-id', '--optimize-level',
                  '--output-type', '--output-path', '--inspect'],
@@ -54,9 +54,9 @@ ac_table = {
                     '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
                     '--max-socket-retries', '--dump-interval', '--read-only', '--separated-workspace', '--memory-hwm',
                     '--skip-on-error', '--num-part', '--max-message-size', '--proxy', '--prefetch',
-                    '--prefetch-on-recv', '--restful', '--rest-api', '--host', '--port-expose', '--port-grpc',
-                    '--port-rest', '--daemon', '--runtime-backend', '--runtime', '--runtime-cls', '--timeout-ready',
-                    '--env', '--expose-public', '--show-exc-info', '--pea-id', '--pea-role'],
+                    '--prefetch-on-recv', '--restful', '--rest-api', '--host', '--port-expose', '--daemon',
+                    '--runtime-backend', '--runtime', '--runtime-cls', '--timeout-ready', '--env', '--expose-public',
+                    '--show-exc-info', '--pea-id', '--pea-role'],
         'ping': ['--help', '--timeout', '--retries', '--print-response'],
         'check': ['--help', '--summary-exec', '--summary-driver'],
         'hub login': ['--help', '--username', '--password', '--registry', '--repository'],
@@ -76,10 +76,9 @@ ac_table = {
                 '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
                 '--max-socket-retries', '--dump-interval', '--read-only', '--separated-workspace', '--memory-hwm',
                 '--skip-on-error', '--num-part', '--uses-internal', '--entrypoint', '--pull-latest', '--volumes',
-                '--host', '--port-expose', '--port-grpc', '--port-rest', '--daemon', '--runtime-backend', '--runtime',
-                '--runtime-cls', '--timeout-ready', '--env', '--expose-public', '--show-exc-info', '--pea-id',
-                '--pea-role'], 'log': ['--help', '--groupby-regex', '--refresh-time'],
+                '--host', '--port-expose', '--daemon', '--runtime-backend', '--runtime', '--runtime-cls',
+                '--timeout-ready', '--env', '--expose-public', '--show-exc-info', '--pea-id', '--pea-role'],
+        'log': ['--help', '--groupby-regex', '--refresh-time'],
         'client': ['--help', '--batch-size', '--mode', '--top-k', '--mime-type', '--continue-on-error',
                    '--return-results', '--max-message-size', '--proxy', '--prefetch', '--prefetch-on-recv', '--restful',
-                   '--rest-api', '--host', '--port-expose', '--port-grpc', '--port-rest'],
-        'export-api': ['--help', '--yaml-path', '--json-path']}}
+                   '--rest-api', '--host', '--port-expose'], 'export-api': ['--help', '--yaml-path', '--json-path']}}
