@@ -54,7 +54,11 @@ class BaseEvaluateDriver(BaseExecutableDriver):
             evaluation.value = self.exec_fn(self.extract(doc), self.extract(groundtruth))
             if self._running_avg:
                 evaluation.value = self.exec.mean
-            evaluation.op_name = self.exec.metric
+
+            if hasattr(self.exec, 'eval_at'):
+                evaluation.op_name = f'{self.exec.__class__.__name__}@{self.exec.eval_at}'
+            else:
+                evaluation.op_name = self.exec.__class__.__name__
             evaluation.ref_id = groundtruth.id
 
     def extract(self, doc: 'Document') -> Any:
